==> openshift-model-config-6.1.1-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FeatureGateListFluent<A extends FeatureGateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,FeatureGate item);
  public A setToItems(Integer index,FeatureGate item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public A addAllToItems(Collection<FeatureGate> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public A removeAllFromItems(Collection<FeatureGate> items);
  public A removeMatchingFromItems(Predicate<FeatureGateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FeatureGate> getItems();
  public List<FeatureGate> buildItems();
  public FeatureGate buildItem(Integer index);
  public FeatureGate buildFirstItem();
  public FeatureGate buildLastItem();
  public FeatureGate buildMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public A withItems(List<FeatureGate> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public Boolean hasItems();
  public FeatureGateListFluent.ItemsNested<A> addNewItem();
  public FeatureGateListFluent.ItemsNested<A> addNewItemLike(FeatureGate item);
  public FeatureGateListFluent.ItemsNested<A> setNewItemLike(Integer index,FeatureGate item);
  public FeatureGateListFluent.ItemsNested<A> editItem(Integer index);
  public FeatureGateListFluent.ItemsNested<A> editFirstItem();
  public FeatureGateListFluent.ItemsNested<A> editLastItem();
  public FeatureGateListFluent.ItemsNested<A> editMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,FeatureGateFluent<FeatureGateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FeatureGateListFluent<A extends FeatureGateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,FeatureGate item);
  public A setToItems(int index,FeatureGate item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public A addAllToItems(Collection<FeatureGate> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public A removeAllFromItems(Collection<FeatureGate> items);
  public A removeMatchingFromItems(Predicate<FeatureGateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FeatureGate> getItems();
  public List<FeatureGate> buildItems();
  public FeatureGate buildItem(int index);
  public FeatureGate buildFirstItem();
  public FeatureGate buildLastItem();
  public FeatureGate buildMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public A withItems(List<FeatureGate> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.FeatureGate... items);
  public Boolean hasItems();
  public FeatureGateListFluent.ItemsNested<A> addNewItem();
  public FeatureGateListFluent.ItemsNested<A> addNewItemLike(FeatureGate item);
  public FeatureGateListFluent.ItemsNested<A> setNewItemLike(int index,FeatureGate item);
  public FeatureGateListFluent.ItemsNested<A> editItem(int index);
  public FeatureGateListFluent.ItemsNested<A> editFirstItem();
  public FeatureGateListFluent.ItemsNested<A> editLastItem();
  public FeatureGateListFluent.ItemsNested<A> editMatchingItem(Predicate<FeatureGateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,FeatureGateFluent<FeatureGateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
